@@ -15,7 +15,9 @@ import pandas as pd
 import mdtraj as md
 
 from .contact_count import ContactCount
+from .atom_indexer import AtomSlicedIndexer, IdentityIndexer
 from .py_2_3 import inspect_method_arguments
+from .fix_parameters import ParameterFixer
 
 # TODO:
 # * switch to something where you can define the haystack -- the trick is to
@@ -25,6 +27,16 @@ from .py_2_3 import inspect_method_arguments
 #   doesn't use voxels, neighborlist doesn't limit the haystack
 
 
+def _residue_and_index(residue, topology):
+    res = residue
+    try:
+        res_idx = res.index
+    except AttributeError:
+        res_idx = residue
+        res = topology.residue(res_idx)
+    return (res, res_idx)
+
+
 def residue_neighborhood(residue, n=1):
     """Find n nearest neighbor residues
 
@@ -47,40 +59,14 @@ def residue_neighborhood(residue, n=1):
     return [idx for idx in neighborhood if idx in chain]
 
 
-def _residue_and_index(residue, topology):
-    res = residue
-    try:
-        res_idx = res.index
-    except AttributeError:
-        res_idx = residue
-        res = topology.residue(res_idx)
-    return (res, res_idx)
-
-
-def _atom_slice(traj, indices):
-    """Mock MDTraj.atom_slice without rebuilding topology"""
-    xyz = np.array(traj.xyz[:, indices], order='C')
-    topology = traj.topology.copy()
-    if traj._have_unitcell:
-        unitcell_lengths = traj._unitcell_lengths.copy()
-        unitcell_angles = traj._unitcell_angles.copy()
-    else:
-        unitcell_lengths = None
-        unitcell_angles = None
-    time = traj._time.copy()
-
-    # Hackish to make the smart slicing work
-    topology._atoms = indices
-    topology._numAtoms = len(indices)
-    return md.Trajectory(xyz=xyz, topology=topology, time=time,
-                         unitcell_lengths=unitcell_lengths,
-                         unitcell_angles=unitcell_angles)
-
-
 def _residue_for_atom(topology, atom_list):
     return set([topology.atom(a).residue for a in atom_list])
 
 
+def _residue_idx_for_atom(topology, atom_list):
+    return set([topology.atom(a).residue.index for a in atom_list])
+
+
 def _range_from_object_list(object_list):
     """
     Objects must have .index attribute (e.g., MDTraj Residue/Atom)
@@ -150,35 +136,25 @@ class ContactObject(object):
 
         # Make tuple for efficient lookupt
         all_atoms_set = set(query).union(set(haystack))
-        all_atoms_list = list(all_atoms_set)
-        all_atoms_list.sort()
-        self._all_atoms = tuple(all_atoms_list)
+        self._all_atoms = tuple(sorted(list(all_atoms_set)))
+        self._all_residues = _residue_idx_for_atom(self._topology,
+                                                   all_atoms_set)
+        self._use_atom_slice = self._set_atom_slice(self._all_atoms)
+        has_indexer = getattr(self, 'indexer', None) is not None
+        if not has_indexer:
+            Indexer = {True: AtomSlicedIndexer,
+                       False: IdentityIndexer}[self.use_atom_slice]
+            self.indexer = Indexer(topology, self._query, self._haystack,
+                                   self._all_atoms)
 
-        self._use_atom_slice = self._set_atom_slice()
-
-        # Set up the conversion dict to go from aton index to sliced indexes
-        self._idx_to_s_idx_dict = {e: i for
-                                   i, e in enumerate(self._all_atoms)}
-
-        # Get the sliced and used haystack indices
-        self._s_haystack = set(map(self.idx_to_s_idx, self._haystack))
-        self._u_haystack = self._set_used_haystack()
         self._n_neighbors_ignored = n_neighbors_ignored
 
-        # Conversion dicts between the real and sliced atoms and their residues
-        self._r_atom_idx_to_residue_idx = {atom.index: atom.residue.index
-                                           for atom in self.topology.atoms}
-        self._s_atom_idx_to_residue_idx = {
-            i: self._r_atom_idx_to_residue_idx[e] for
-            i, e in enumerate(self._all_atoms)
-        }
-        self._atom_idx_to_residue_idx = self._set_atom_idx_to_residue_idx()
-
     @classmethod
     def from_contacts(cls, atom_contacts, residue_contacts, topology,
                       query=None, haystack=None, cutoff=0.45,
-                      n_neighbors_ignored=2):
+                      n_neighbors_ignored=2, indexer=None):
         obj = cls.__new__(cls)
+        obj.indexer = indexer
         super(cls, obj).__init__(topology, query, haystack, cutoff,
                                  n_neighbors_ignored)
 
@@ -192,10 +168,10 @@ class ContactObject(object):
         obj._residue_contacts = get_contact_counter(residue_contacts)
         return obj
 
-    def _set_atom_slice(self):
+    def _set_atom_slice(self, all_atoms):
         """ Set atom slice logic """
         if (self._class_use_atom_slice is None and
-            not len(self._all_atoms) < self._topology.n_atoms):
+            not len(all_atoms) < self._topology.n_atoms):
             # Don't use if there are no atoms to be sliced
             return False
         elif self._class_use_atom_slice is None:
@@ -205,34 +181,6 @@ class ContactObject(object):
             # Use class default
             return self._class_use_atom_slice
 
-    def _set_used_haystack(self):
-        """set which haystack to use in contact map"""
-        if self._use_atom_slice:
-            return self._s_haystack
-        else:
-            return self._haystack
-
-    def _set_atom_idx_to_residue_idx(self):
-        """set which atom index to residue index is used"""
-        if self._use_atom_slice:
-            return self._s_atom_idx_to_residue_idx
-        else:
-            return self._r_atom_idx_to_residue_idx
-
-    def s_idx_to_idx(self, idx):
-        """function to convert a sliced atom index back to real index"""
-        if self._use_atom_slice:
-            return self._all_atoms[idx]
-        else:
-            return idx
-
-    def idx_to_s_idx(self, idx):
-        """function to convert a real atom index to a sliced one"""
-        if self._use_atom_slice:
-            return self._idx_to_s_idx_dict[idx]
-        else:
-            return idx
-
     @property
     def contacts(self):
         """:class:`.ContactsDict` : contact dict for these contacts"""
@@ -268,11 +216,12 @@ class ContactObject(object):
             'haystack': list([int(val) for val in self._haystack]),
             'all_atoms': tuple(
                 [int(val) for val in self._all_atoms]),
+            'all_residues': tuple(
+                [int(val) for val in self._all_residues]),
             'n_neighbors_ignored': self._n_neighbors_ignored,
-            'atom_idx_to_residue_idx': self._atom_idx_to_residue_idx,
-            'atom_contacts': \
+            'atom_contacts':
                 self._serialize_contact_counter(self._atom_contacts),
-            'residue_contacts': \
+            'residue_contacts':
                 self._serialize_contact_counter(self._residue_contacts),
             'use_atom_slice': self._use_atom_slice}
         return dct
@@ -299,6 +248,7 @@ class ContactObject(object):
             'query': deserialize_set,
             'haystack': deserialize_set,
             'all_atoms': deserialize_set,
+            'all_residues': deserialize_set,
             'atom_idx_to_residue_idx': deserialize_atom_to_residue_dct
         }
         for key in deserialization_helpers:
@@ -380,19 +330,22 @@ class ContactObject(object):
         compatibility_attrs = ['cutoff', 'topology', 'query', 'haystack',
                                'n_neighbors_ignored']
         failed_attr = {}
+        err_msg = ""
         for attr in compatibility_attrs:
             self_val = getattr(self, attr)
             other_val = getattr(other, attr)
             if self_val != other_val:
-                failed_attr.update({attr: (self_val, other_val)})
+                failed_attr[attr] = (self_val, other_val)
+                err_msg += "        {attr}: {self} != {other}\n".format(
+                    attr=attr, self=str(self_val), other=str(other_val)
+                )
+
         msg = "Incompatible ContactObjects:\n"
-        for (attr, vals) in failed_attr.items():
-            msg += "        {attr}: {self} != {other}\n".format(
-                attr=attr, self=str(vals[0]), other=str(vals[1])
-            )
-        if failed_attr:
+        msg += err_msg
+        if failed_attr and err is not None:
             raise err(msg)
-        return True
+        else:
+            return failed_attr
 
     def save_to_file(self, filename, mode="w"):
         """Save this object to the given file.
@@ -481,22 +434,11 @@ class ContactObject(object):
         return self._use_atom_slice
 
     @property
-    def residue_query_atom_idxs(self):
-        """dict : maps query residue index to atom indices in query"""
-        result = collections.defaultdict(list)
-        for atom_idx in self._query:
-            residue_idx = self._r_atom_idx_to_residue_idx[atom_idx]
-            if self.use_atom_slice:
-                atom_idx = self._idx_to_s_idx_dict[atom_idx]
-            result[residue_idx].append(atom_idx)
-        return result
-
-    @property
-    def residue_ignore_atom_idxs(self):
+    def _residue_ignore_atom_idxs(self):
         """dict : maps query residue index to atom indices to ignore"""
         all_atoms_set = set(self._all_atoms)
         result = {}
-        for residue_idx in self.residue_query_atom_idxs.keys():
+        for residue_idx in self.indexer.residue_query_atom_idxs.keys():
             residue = self.topology.residue(residue_idx)
             # Several steps to go residue indices -> atom indices
             ignore_residue_idxs = residue_neighborhood(
@@ -507,18 +449,11 @@ class ContactObject(object):
                                for idx in ignore_residue_idxs]
             ignore_atoms = sum([list(res.atoms)
                                 for res in ignore_residues], [])
-            ignore_atom_idxs = self._ignore_atom_idx(ignore_atoms,
-                                                     all_atoms_set)
+            ignore_atom_idxs = self.indexer.ignore_atom_idx(ignore_atoms,
+                                                            all_atoms_set)
             result[residue_idx] = ignore_atom_idxs
         return result
 
-    def _ignore_atom_idx(self, atoms, all_atoms_set):
-        result = set([atom.index for atom in atoms])
-        if self._use_atom_slice:
-            result &= all_atoms_set
-            result = set(map(self.idx_to_s_idx, result))
-        return result
-
     @property
     def haystack_residues(self):
         """list : residues for atoms in the haystack"""
@@ -602,19 +537,8 @@ class ContactObject(object):
                   if frozenset(contact[0]) in all_atom_pairs]
         return result
 
-    def slice_trajectory(self, trajectory):
-        # Prevent (memory) expensive atom slicing if not needed.
-        # This check is also needed here because ContactFrequency slices the
-        # whole trajectory before calling this function.
-        if self.use_atom_slice and (len(self._all_atoms) <
-                                    trajectory.topology.n_atoms):
-            sliced_trajectory = _atom_slice(trajectory, self._all_atoms)
-        else:
-            sliced_trajectory = trajectory
-        return sliced_trajectory
-
-    def contact_map(self, trajectory, frame_number, residue_query_atom_idxs,
-                    residue_ignore_atom_idxs):
+    def _contact_map(self, trajectory, frame_number, residue_query_atom_idxs,
+                     residue_ignore_atom_idxs):
         """
         Returns atom and residue contact maps for the given frame.
 
@@ -630,13 +554,15 @@ class ContactObject(object):
         atom_contacts : collections.Counter
         residue_contact : collections.Counter
         """
-        used_trajectory = self.slice_trajectory(trajectory)
+        used_trajectory = self.indexer.slice_trajectory(trajectory)
 
         neighborlist = md.compute_neighborlist(used_trajectory, self.cutoff,
                                                frame_number)
 
         contact_pairs = set([])
         residue_pairs = set([])
+        haystack = self.indexer.haystack
+        atom_idx_to_residue_idx = self.indexer.atom_idx_to_residue_idx
         for residue_idx in residue_query_atom_idxs:
             ignore_atom_idxs = set(residue_ignore_atom_idxs[residue_idx])
             query_idxs = residue_query_atom_idxs[residue_idx]
@@ -645,7 +571,7 @@ class ContactObject(object):
                 # should be small and s-t is avg cost len(s)
                 neighbor_idxs = set(neighborlist[atom_idx])
                 contact_neighbors = neighbor_idxs - ignore_atom_idxs
-                contact_neighbors = contact_neighbors & self._u_haystack
+                contact_neighbors = contact_neighbors & haystack
                 # frozenset is unique key independent of order
                 # local_pairs = set(frozenset((atom_idx, neighb))
                 #                   for neighb in contact_neighbors)
@@ -656,7 +582,7 @@ class ContactObject(object):
                 contact_pairs |= local_pairs
                 # contact_pairs |= set(frozenset((atom_idx, neighb))
                 #                      for neighb in contact_neighbors)
-                local_residue_partners = set(self._atom_idx_to_residue_idx[a]
+                local_residue_partners = set(atom_idx_to_residue_idx[a]
                                              for a in contact_neighbors)
                 local_res_pairs = set(map(
                     frozenset,
@@ -672,14 +598,6 @@ class ContactObject(object):
         residue_contacts = collections.Counter(residue_pairs)
         return (atom_contacts, residue_contacts)
 
-    def convert_atom_contacts(self, atom_contacts):
-        if self._use_atom_slice:
-            result = {frozenset(tuple(map(self.s_idx_to_idx, key))): value
-                      for key, value in atom_contacts.items()}
-            return collections.Counter(result)
-        else:
-            return atom_contacts
-
     @property
     def atom_contacts(self):
         n_atoms = self.topology.n_atoms
@@ -693,61 +611,12 @@ class ContactObject(object):
                             n_res, n_res)
 
 
-class ContactMap(ContactObject):
-    """
-    Contact map (atomic and residue) for a single frame.
-
-    .. deprecated:: 0.6.0
-        ``ContactMap`` will be removed in Contact Map Explorer 0.7.0 because
-        it is redundant with ``ContactFrequency``. For more, see
-        https://github.com/dwhswenson/contact_map/issues/82.
-
-    """
-    # Default for use_atom_slice, None tries to be smart
-    _class_use_atom_slice = None
-
-    _deprecation_message=(
-        "The ContactMap class will be removed in Contact Map Explorer 0.7. "
-        + "Use ContactFrequency instead. For more, see: "
-        + "https://github.com/dwhswenson/contact_map/issues/82."
-    )
-
-    def __init__(self, frame, query=None, haystack=None, cutoff=0.45,
-                 n_neighbors_ignored=2):
-        warnings.warn(self._deprecation_message, FutureWarning)
-        self._frame = frame  # TODO: remove this?
-        super(ContactMap, self).__init__(frame.topology, query, haystack,
-                                         cutoff, n_neighbors_ignored)
-
-        contact_maps = self.contact_map(frame, 0,
-                                        self.residue_query_atom_idxs,
-                                        self.residue_ignore_atom_idxs)
-        (atom_contacts, self._residue_contacts) = contact_maps
-        self._atom_contacts = self.convert_atom_contacts(atom_contacts)
-
-    @classmethod
-    def from_dict(cls, dct):
-        warnings.warn(cls._deprecation_message, FutureWarning)
-        return super(ContactMap, cls).from_dict(dct)
-
-    # don't need to add deprecation in from_json because it uses from_dict
-
-    @classmethod
-    def from_file(cls, filename):
-        warnings.warn(cls._deprecation_message, FutureWarning)
-        return super(ContactMap, cls).from_file(filename)
-
-
-    def __hash__(self):
-        return hash((super(ContactMap, self).__hash__(),
-                     tuple(self._atom_contacts.items()),
-                     tuple(self._residue_contacts.items())))
-
-    def __eq__(self, other):
-        is_equal = (super(ContactMap, self).__eq__(other)
-                    and self._atom_contacts == other._atom_contacts
-                    and self._residue_contacts == other._residue_contacts)
-        return is_equal
+CONTACT_MAP_ERROR = (
+    "The ContactMap class has been removed. Please use ContactFrequency."
+    " For more, see: https://github.com/dwhswenson/contact_map/issues/82"
+)
+def ContactMap(*args, **kwargs):  # -no-cov-
+    raise RuntimeError(CONTACT_MAP_ERROR)
 
 
 class ContactFrequency(ContactObject):
@@ -774,18 +643,19 @@ class ContactFrequency(ContactObject):
     n_neighbors_ignored : int
         Number of neighboring residues (in the same chain) to ignore.
         Default 2.
-    frames : list of int
-        The indices of the frames to use from the trajectory. Default all
     """
     # Default for use_atom_slice, None tries to be smart
     _class_use_atom_slice = None
+    _pending_dep_msg = (
+        "ContactFrequency will be renamed to ContactMap in version 0.8. "
+        "Invoking it as ContactFrequency will be deprecated in 0.8. For "
+        "more, see https://github.com/dwhswenson/contact_map/issues/82"
+    )
 
     def __init__(self, trajectory, query=None, haystack=None, cutoff=0.45,
-                 n_neighbors_ignored=2, frames=None):
-        if frames is None:
-            frames = range(len(trajectory))
-        self.frames = frames
-        self._n_frames = len(frames)
+                 n_neighbors_ignored=2):
+        warnings.warn(self._pending_dep_msg, PendingDeprecationWarning)
+        self._n_frames = len(trajectory)
         super(ContactFrequency, self).__init__(trajectory.topology,
                                                query, haystack, cutoff,
                                                n_neighbors_ignored)
@@ -795,14 +665,25 @@ class ContactFrequency(ContactObject):
     @classmethod
     def from_contacts(cls, atom_contacts, residue_contacts, n_frames,
                       topology, query=None, haystack=None, cutoff=0.45,
-                      n_neighbors_ignored=2):
+                      n_neighbors_ignored=2, indexer=None):
+        warnings.warn(cls._pending_dep_msg, PendingDeprecationWarning)
         obj = super(ContactFrequency, cls).from_contacts(
             atom_contacts, residue_contacts, topology, query, haystack,
-            cutoff, n_neighbors_ignored
+            cutoff, n_neighbors_ignored, indexer
         )
         obj._n_frames = n_frames
         return obj
 
+    @classmethod
+    def from_dict(cls, dct):
+        warnings.warn(cls._pending_dep_msg, PendingDeprecationWarning)
+        return super(ContactFrequency, cls).from_dict(dct)
+
+    @classmethod
+    def from_file(cls, filename):
+        warnings.warn(cls._pending_dep_msg, PendingDeprecationWarning)
+        return super(ContactFrequency, cls).from_file(filename)
+
     def __hash__(self):
         return hash((super(ContactFrequency, self).__hash__(),
                      tuple(self._atom_contacts.items()),
@@ -833,20 +714,21 @@ class ContactFrequency(ContactObject):
 
         # cache things that can be calculated once based on the topology
         # (namely, which atom indices matter for each residue)
-        residue_ignore_atom_idxs = self.residue_ignore_atom_idxs
-        residue_query_atom_idxs = self.residue_query_atom_idxs
+        residue_ignore_atom_idxs = self._residue_ignore_atom_idxs
+        residue_query_atom_idxs = self.indexer.residue_query_atom_idxs
 
-        used_trajectory = self.slice_trajectory(trajectory)
-        for frame_num in self.frames:
-            frame_contacts = self.contact_map(used_trajectory, frame_num,
-                                              residue_query_atom_idxs,
-                                              residue_ignore_atom_idxs)
+        used_trajectory = self.indexer.slice_trajectory(trajectory)
+        for frame_num in range(len(trajectory)):
+            frame_contacts = self._contact_map(used_trajectory, frame_num,
+                                               residue_query_atom_idxs,
+                                               residue_ignore_atom_idxs)
             frame_atom_contacts = frame_contacts[0]
             frame_residue_contacts = frame_contacts[1]
-            # self._atom_contacts_count += frame_atom_contacts
             atom_contacts_count.update(frame_atom_contacts)
             residue_contacts_count += frame_residue_contacts
-        atom_contacts_count = self.convert_atom_contacts(atom_contacts_count)
+
+        atom_contacts_count = \
+                self.indexer.convert_atom_contacts(atom_contacts_count)
         return (atom_contacts_count, residue_contacts_count)
 
     @property
@@ -911,27 +793,41 @@ class ContactFrequency(ContactObject):
 class ContactDifference(ContactObject):
     """
     Contact map comparison (atomic and residue).
-
     This can compare single frames or entire trajectories (or even mix the
     two!) While this can be directly instantiated by the user, the more
     common way to make this object is by using the ``-`` operator, i.e.,
     ``diff = map_1 - map_2``.
     """
+    # Some class variables on how we handle mismatches, mainly for subclassing.
+    _allow_mismatched_atoms = False
+    _allow_mismatched_residues = False
+    _override_topology = True
+
     def __init__(self, positive, negative):
         self.positive = positive
         self.negative = negative
-        positive._check_compatibility(negative)
-        super(ContactDifference, self).__init__(positive.topology,
-                                                positive.query,
-                                                positive.haystack,
-                                                positive.cutoff,
-                                                positive.n_neighbors_ignored)
+        fix_parameters = ParameterFixer(
+            allow_mismatched_atoms=self._allow_mismatched_atoms,
+            allow_mismatched_residues=self._allow_mismatched_residues,
+            override_topology=self._override_topology)
+
+        (topology, query,
+         haystack, cutoff,
+         n_neighbors_ignored) = fix_parameters.get_parameters(positive,
+                                                              negative)
+        self._all_atoms_intersect = set(
+            positive._all_atoms).intersection(negative._all_atoms)
+        self._all_residues_intersect = set(
+            positive._all_residues).intersection(negative._all_residues)
+        super(ContactDifference, self).__init__(topology,
+                                                query,
+                                                haystack,
+                                                cutoff,
+                                                n_neighbors_ignored)
 
     def to_dict(self):
         """Convert object to a dict.
-
         Keys should be strings; values should be (JSON-) serializable.
-
         See also
         --------
         from_dict
@@ -946,12 +842,10 @@ class ContactDifference(ContactObject):
     @classmethod
     def from_dict(cls, dct):
         """Create object from dict.
-
         Parameters
         ----------
         dct : dict
             dict-formatted serialization (see to_dict for details)
-
         See also
         --------
         to_dict
@@ -986,16 +880,99 @@ class ContactDifference(ContactObject):
 
     @property
     def atom_contacts(self):
-        n_x = self.topology.n_atoms
-        n_y = self.topology.n_atoms
-        diff = collections.Counter(self.positive.atom_contacts.counter)
-        diff.subtract(self.negative.atom_contacts.counter)
-        return ContactCount(diff, self.topology.atom, n_x, n_y)
+        return self._get_filtered_sub(pos_count=self.positive.atom_contacts,
+                                      neg_count=self.negative.atom_contacts,
+                                      selection=self._all_atoms_intersect,
+                                      object_f=self.topology.atom,
+                                      n_x=self.topology.n_atoms,
+                                      n_y=self.topology.n_atoms)
 
     @property
     def residue_contacts(self):
-        n_x = self.topology.n_residues
-        n_y = self.topology.n_residues
-        diff = collections.Counter(self.positive.residue_contacts.counter)
-        diff.subtract(self.negative.residue_contacts.counter)
-        return ContactCount(diff, self.topology.residue, n_x, n_y)
+        return self._get_filtered_sub(pos_count=self.positive.residue_contacts,
+                                      neg_count=self.negative.residue_contacts,
+                                      selection=self._all_residues_intersect,
+                                      object_f=self.topology.residue,
+                                      n_x=self.topology.n_residues,
+                                      n_y=self.topology.n_residues)
+
+    def _get_filtered_sub(self, pos_count, neg_count, selection, *args,
+                          **kwargs):
+        """Get a filtered subtraction between two ContactCounts"""
+        filtered_pos = pos_count.filter(selection)
+        filtered_neg = neg_count.filter(selection)
+        diff = collections.Counter(filtered_pos.counter)
+        diff.subtract(filtered_neg.counter)
+        return ContactCount(diff, *args, **kwargs)
+
+
+class AtomMismatchedContactDifference(ContactDifference):
+    """
+    Contact map comparison (only residues).
+    """
+    _allow_mismatched_atoms = True
+
+    def most_common_atoms_for_contact(self, *args, **kwargs):
+        self._missing_atom_contacts()
+
+    def most_common_atoms_for_residue(self, *args, **kwargs):
+        self._missing_atom_contacts()
+
+    @property
+    def atom_contacts(self):
+        self._missing_atom_contacts()
+
+    @property
+    def haystack_residues(self):
+        self._missing_atom_contacts()
+
+    @property
+    def query_residues(self):
+        self._missing_atom_contacts()
+
+    def _missing_atom_contacts(self):
+        raise RuntimeError("Different atom indices involved between the two"
+                           " maps, so this does not make sense.")
+
+
+class ResidueMismatchedContactDifference(ContactDifference):
+    """
+    Contact map comparison (only atoms).
+    """
+    _allow_mismatched_residues = True
+
+    @property
+    def residue_contacts(self):
+        self._missing_residue_contacts()
+
+    @property
+    def _residue_ignore_atom_idxs(self):
+        self._missing_residue_contacts()
+
+    def most_common_atoms_for_contact(self, *args, **kwargs):
+        self._missing_residue_contacts()
+
+    def most_common_atoms_for_residue(self, *args, **kwargs):
+        self._missing_residue_contacts()
+
+    @property
+    def haystack_residues(self):
+        self._missing_residue_contacts()
+
+    @property
+    def query_residues(self):
+        self._missing_residue_contacts()
+
+    def _missing_residue_contacts(self):
+        raise RuntimeError("Different residue indices involved between the two"
+                           " maps, so this does not make sense.")
+
+
+class OverrideTopologyContactDifference(ContactDifference):
+    """
+    Contact map comparison with a user provided Topology.
+    """
+
+    def __init__(self, positive, negative, topology):
+        self._override_topology = topology
+        super().__init__(positive, negative)
